;; Generated package description from yaml.el  -*- no-byte-compile: t -*-
(define-package "yaml" "1.2.0" "YAML parser for Elisp" '((emacs "25.1")) :commit "09e46d563f1f3ff948852e08360c7d3c76e2acba" :authors '(("Zachary Romero" . "zkry@posteo.org")) :maintainer '("Zachary Romero" . "zkry@posteo.org") :keywords '("tools") :url "https://github.com/zkry/yaml.el")
